@@ -56,19 +56,19 @@ public:
     };
 
     static Akonadi::CalendarModel::Ptr create(Akonadi::Monitor *monitor);
-    ~CalendarModel();
+    ~CalendarModel() override;
 
-    QWeakPointer<CalendarModel> weakPointer() const;
+    Q_REQUIRED_RESULT QWeakPointer<CalendarModel> weakPointer() const;
     void setWeakPointer(const QWeakPointer<CalendarModel> &weakPointer);
 
-    QVariant entityData(const Akonadi::Item &item, int column, int role = Qt::DisplayRole) const override;
+    Q_REQUIRED_RESULT QVariant entityData(const Akonadi::Item &item, int column, int role = Qt::DisplayRole) const override;
 
-    QVariant entityData(const Akonadi::Collection &collection, int column,
+    Q_REQUIRED_RESULT QVariant entityData(const Akonadi::Collection &collection, int column,
                         int role = Qt::DisplayRole) const override;
 
-    int entityColumnCount(EntityTreeModel::HeaderGroup headerSet) const override;
+    Q_REQUIRED_RESULT int entityColumnCount(EntityTreeModel::HeaderGroup headerSet) const override;
 
-    QVariant entityHeaderData(int section, Qt::Orientation orientation, int role,
+    Q_REQUIRED_RESULT QVariant entityHeaderData(int section, Qt::Orientation orientation, int role,
                               EntityTreeModel::HeaderGroup headerSet) const override;
 
 private:
