@@ -65,8 +65,9 @@ void ETMCalendarPrivate::init()
     if (!mETM) {
         Akonadi::Session *session = new Akonadi::Session("ETMCalendar", q);
         Akonadi::Monitor *monitor = new Akonadi::Monitor(q);
-        connect(monitor, SIGNAL(collectionChanged(Akonadi::Collection,QSet<QByteArray>)),
-                SLOT(onCollectionChanged(Akonadi::Collection,QSet<QByteArray>)));
+        monitor->setObjectName(QStringLiteral("ETMCalendarMonitor"));
+        connect(monitor, QOverload<const Akonadi::Collection &, const QSet<QByteArray> &>::of(&Monitor::collectionChanged), this, [this]( const Akonadi::Collection &cols, const QSet<QByteArray> &set)
+        { onCollectionChanged(cols, set);});
 
         Akonadi::ItemFetchScope scope;
         scope.fetchFullPayload(true);
@@ -492,8 +493,7 @@ ETMCalendar::ETMCalendar(Monitor *monitor, QObject *parent)
     Q_D(ETMCalendar);
 
     if (monitor) {
-        QObject::connect(monitor, static_cast<void (Akonadi::Monitor::*)(const Akonadi::Collection &, const QSet<QByteArray> &)>(&Akonadi::Monitor::collectionChanged),
-                         d, &ETMCalendarPrivate::onCollectionChanged);
+        QObject::connect(monitor, QOverload<const Akonadi::Collection &, const QSet<QByteArray> &>::of(&Akonadi::Monitor::collectionChanged), d, &ETMCalendarPrivate::onCollectionChanged);
         d->mETM = CalendarModel::create(monitor);
         d->mETM->setObjectName(QStringLiteral("ETM"));
         d->mETM->setListFilter(Akonadi::CollectionFetchScope::Display);
@@ -539,8 +539,8 @@ KCheckableProxyModel *ETMCalendar::checkableProxyModel() const
     return d->mCheckableProxyModel;
 }
 
-KCalCore::Alarm::List ETMCalendar::alarms(const KDateTime &from,
-        const KDateTime &to,
+KCalCore::Alarm::List ETMCalendar::alarms(const QDateTime &from,
+        const QDateTime &to,
         bool excludeBlockedAlarms) const
 {
     Q_D(const ETMCalendar);
