@@ -179,7 +179,7 @@ FreeBusyManagerPrivate::FreeBusyManagerPrivate(FreeBusyManager *q)
 
 QString FreeBusyManagerPrivate::freeBusyDir() const
 {
-    return QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("korganizer/freebusy");
+    return QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/korganizer/freebusy");
 }
 
 void FreeBusyManagerPrivate::checkFreeBusyUrl()
@@ -190,7 +190,7 @@ void FreeBusyManagerPrivate::checkFreeBusyUrl()
 
 static QString configFile()
 {
-    static QString file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("korganizer/freebusyurls");
+    static QString file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/korganizer/freebusyurls");
     return file;
 }
 
@@ -555,7 +555,7 @@ QStringList FreeBusyManagerPrivate::getFreeBusyProviders() const
     QStringList providers;
     const Akonadi::AgentInstance::List agents = Akonadi::AgentManager::self()->instances();
     for (const Akonadi::AgentInstance &agent : agents) {
-        if (agent.type().capabilities().contains(QStringLiteral("FreeBusyProvider"))) {
+        if (agent.type().capabilities().contains(QLatin1String("FreeBusyProvider"))) {
             providers << agent.identifier();
         }
     }
@@ -964,7 +964,12 @@ bool FreeBusyManager::retrieveFreeBusy(const QString &email, bool forceDownload,
 
     // queued, because "true" means the download was initiated. So lets
     // return before starting stuff
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    QMetaObject::invokeMethod(d, [this, d] { d->processRetrieveQueue(); }, Qt::QueuedConnection);
+#else
     QMetaObject::invokeMethod(d, "processRetrieveQueue", Qt::QueuedConnection);
+#endif
+
     return true;
 }
 
